pub struct RunOpt {
pub study: Option<String>,
pub repeats: usize,
pub command: String,
pub args: Vec<String>,
}Fields
study: Option<String>repeats: usizecommand: Stringargs: Vec<String>Trait Implementations
Sourceimpl StructOpt for RunOpt
impl StructOpt for RunOpt
Sourcefn from_clap(matches: &ArgMatches<'_>) -> Self
fn from_clap(matches: &ArgMatches<'_>) -> Self
Creates the struct from
clap::ArgMatches. It cannot fail
with a parameter generated by clap by construction.Sourcefn from_args() -> Selfwhere
Self: Sized,
fn from_args() -> Selfwhere
Self: Sized,
Gets the struct from the command line arguments. Print the
error message and quit the program in case of failure.
Sourcefn from_iter<I>(iter: I) -> Self
fn from_iter<I>(iter: I) -> Self
Gets the struct from any iterator such as a
Vec of your making.
Print the error message and quit the program in case of failure.Auto Trait Implementations
impl Freeze for RunOpt
impl RefUnwindSafe for RunOpt
impl Send for RunOpt
impl Sync for RunOpt
impl Unpin for RunOpt
impl UnsafeUnpin for RunOpt
impl UnwindSafe for RunOpt